@@ -1,5 +1,6 @@
-from downloader import *
+from PyQt5 import QtCore, QtGui, QtWidgets
 from PyQt5.Qt import *
+from PyQt5.uic import *
 from PyQt5.QtCore import *
 from PyQt5.QtWidgets import *
 import sys
@@ -7,14 +8,70 @@ import requests
 import os
 import datetime
 import time
+import colorama
+
+print(f'[{time.ctime()}][main/Info] modules initlazed')
+
+Ui_MainWindow,_ = loadUiType('downloader.ui')
 class window(QtWidgets.QMainWindow,Ui_MainWindow):
     def __init__(self):
+        print(f'[{time.ctime()}][main/Info] loading')
         super(window,self).__init__()
         self.setupUi(self)
         self.pushButton.clicked.connect(self.download)
         self.te = ''
         self.progressBar.setValue(0)
+        try:
+            self.load()
+            print(f'[{time.ctime()}][main/Info] load settings.properties sucsess')
+        except BaseException as e:
+
+            print(f'[{time.ctime()}][main/Error] error in initlazing:{e}'+colorama.Fore.RED)
+
+            print(r'*\**:( Downloader Crashed! ):**/*'+colorama.Fore.RED)
+            sys.exit(self.show())
+
+        self.timer = QTimer()
+        self.timer.timeout.connect(self.write)
+        self.timer.start(500)
+        print(f'[{time.ctime()}][main/Info] timer initlazing sucsess')
+    def load(self):
+        a = open('properties/settings.properties')
+
+        dic = eval(a.read())
+        if dic[0]:
+            self.checkBox.toggle()
+        if dic[1]:
+            self.checkBox_2.toggle()
+        if dic[2]:
+            self.checkBox_3.toggle()
+        self.lineEdit.setText(dic[3])
+        self.lineEdit_2.setText(dic[4])
+    def write(self):
+        a = open('properties/settings.properties','w')
+        dic = [None,None,None,None,None]
+        if self.checkBox.isChecked():
+            dic[0] = True
+        else:
+            dic[0] = False
+
+        if self.checkBox_2.isChecked():
+            dic[1] = True
+        else:
+            dic[1] = False
+
+        if self.checkBox_3.isChecked():
+            dic[2] = True
+        else:
+            dic[2] = False
+        dic[3] = self.lineEdit.text()
+        dic[4] = self.lineEdit_2.text()
+
+        a.write(str(dic))
+
+
     def download(self):
+        print(f'[{time.ctime()}][main/Info] Downloading')
         self.u(0)
         a = datetime.datetime.now()
         self.u(1)
@@ -67,6 +124,7 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
             x = b-a
             x = x.total_seconds()
             if not self.checkBox_2.isChecked():
+                print(f'[{time.ctime()}][main/Info] Download from {self.lineEdit.text()} sucsess')
                 size = float(os.path.getsize(aaaaa))
                 if size >= 1024 and size <= 1024*1024:
                     self.update(f'sucsess in {x}s({size/1024}KB,{size/1024/x}KB/s)')
@@ -80,12 +138,17 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
                     self.update(f'sucsess in {x}s({size}B,{size/x}B/s)')
             else:
                 self.update(f'sucsess in {x}s')
+                print(f'[{time.ctime()}][main/Info] Download from {self.lineEdit.text()} sucsess')
+
         except BaseException as e:
             self.u(0)
             if not self.checkBox_3.isChecked():
                 self.update(f'error:{e}')
             else:
                 self.update(f'failed')
+            print(f'[{time.ctime()}][main/Error] error in download:{e},ignored'+colorama.Fore.RED)
+
+
 
 
 
